@@ -1,8 +1,9 @@
 from pathlib import Path
 
 
-def create_dir(dir_name: str):
+def _create_dir(dir_name: str):
     """
+    create project dir
     :param dir_name: create dir use dir name
     :return: None
     """
@@ -13,4 +14,4 @@ def create_dir(dir_name: str):
 
 
 def create_template_dir():
-    create_dir("je_load_density/template")
+    _create_dir("je_load_density/template")
